@@ -393,7 +393,7 @@ micro_hash_release (MicroHash *hash_table)
 static void
 micro_hash_init (MicroHash *hash_table, gpointer key)
 {
-	hash_table->num_elements = 0;
+	hash_table->num_elements = 1;
 	hash_table->num_buckets = 1;
 	hash_table->u.singleton = g_slist_prepend (NULL, key);
 }
@@ -761,7 +761,7 @@ handle_tree_deps (Dependent *dep, CellPos const *pos,
 			expr_name_add_dep (tree->name.name, dep);
 		else
 			expr_name_remove_dep (tree->name.name, dep);
-		if (!tree->name.name->builtin)
+		if (!tree->name.name->builtin && tree->name.name->active)
 			handle_tree_deps (dep, pos, tree->name.name->t.expr_tree, operation);
 		return;
 
@@ -865,7 +865,7 @@ dependent_unlink (Dependent *dep, CellPos const *pos)
 			handle_tree_deps (dep, pos, dep->expression, REMOVE_DEPS);
 			UNLINK_DEP (dep);
 /* FIXME FIXME FIXME : Massive hack !  rework dependent linkage cycle after release */
-		} if (!dependent_is_cell (dep))
+		} else if (!dependent_is_cell (dep))
 			handle_tree_deps (dep, pos, dep->expression, REMOVE_DEPS);
 
 		dep->flags &= ~(DEPENDENT_IN_EXPR_LIST | DEPENDENT_NEEDS_RECALC);
@@ -1238,12 +1238,20 @@ cb_dep_hash_invalidate (gpointer key, gpointer value, gpointer closure)
 }
 
 static void
-cb_name_invalidate_sheet (gpointer key, gpointer value, gpointer rwinfo)
+cb_name_invalidate (NamedExpression *nexpr, gpointer value,
+		    ExprRewriteInfo const *rwinfo)
 {
-	NamedExpression *nexpr = key;
-	ExprTree *new_expr = expr_rewrite (nexpr->t.expr_tree, rwinfo);
-	g_return_if_fail (new_expr != NULL);
-	expr_name_set_expr (nexpr, new_expr);
+	ExprTree *new_expr = NULL;
+
+	if (!nexpr->builtin &&
+	    ((rwinfo->type == EXPR_REWRITE_SHEET &&
+	     rwinfo->u.sheet != nexpr->pos.sheet) ||
+	    (rwinfo->type == EXPR_REWRITE_WORKBOOK &&
+	     rwinfo->u.workbook == nexpr->pos.wb))) {
+		new_expr = expr_rewrite (nexpr->t.expr_tree, rwinfo);
+		g_return_if_fail (new_expr != NULL);
+	}
+	expr_name_set_expr (nexpr, new_expr, rwinfo);
 }
 
 /*
@@ -1292,7 +1300,7 @@ do_deps_destroy (Sheet *sheet, ExprRewriteInfo const *rwinfo)
 
 	if (deps->names) {
 		g_hash_table_foreach (deps->names, 
-			cb_name_invalidate_sheet, (gpointer)rwinfo);
+			(GHFunc) cb_name_invalidate, (gpointer)rwinfo);
 		g_hash_table_destroy (deps->names);
 		deps->names = NULL;
 	}
