@@ -34,7 +34,7 @@ typedef enum {
 
 /* The order corresponds to the border_buttons name list
  * in dialog_cell_format_impl */
-enum _StyleBorderLocation {
+typedef enum _StyleBorderLocation {
 	STYLE_BORDER_TOP,	STYLE_BORDER_BOTTOM,
 	STYLE_BORDER_LEFT,	STYLE_BORDER_RIGHT,
 	STYLE_BORDER_REV_DIAG,	STYLE_BORDER_DIAG,
@@ -46,7 +46,7 @@ enum _StyleBorderLocation {
 	STYLE_BORDER_HORIZ, STYLE_BORDER_VERT,
 
 	STYLE_BORDER_EDGE_MAX
-};
+} StyleBorderLocation;
 
 struct _StyleBorder {
 	/* Key elements */
@@ -79,10 +79,17 @@ void style_borders_row_draw  (StyleBorder const * const * prev_vert,
 			      GdkDrawable *drawable,
 			      int x, int y1, int y2,
 			      int *colwidths, gboolean draw_vertical);
+void style_border_draw_diag  (MStyle const *style,
+			      GdkDrawable *drawable,
+			      int x1, int y1, int x2, int y2);
+
 void style_borders_row_print (StyleBorder const * const * prev_vert,
 			      StyleRow const *sr,
 			      GnomePrintContext *context,
 			      float x, float y1, float y2,
 			      Sheet const *sheet, gboolean draw_vertical);
+void style_border_print_diag (MStyle const *style,
+			      GnomePrintContext *context,
+			      float x1, float y1, float x2, float y2);
 
 #endif /* GNUMERIC_STYLE_BORDER_H */
